capture log close
set more off
clear

log using "~/dropbox/wsp/programs/common-v2-2011-09-09/0 EXAMPLE-india.log", text replace
* EXAMPLE-peru.do
* template to run all common modules and merge them into 
* a derived variable dataset at each level of the data
* (household, child, caregiver, structured observation)
*
* The programs assume you are running them on a panel dataset with
* baseline and endline data.  Some of the programs require a variable
* called "survid", with 1=Baseline and 2=Endline to differentiate 
* between survey rounds.
*
* Example based on the India datasets.

* To run the programs, modify the local macros in the INPUT
* section, below
* 
* Due to the WHO anthropometric Z-score algorithm, it is
* recommended that you run this in a fresh session of Stata.


*--------------------------------------------
* INPUT
* Specify file directories and file names
*--------------------------------------------

* data files: 
* household, child, caregiver (no SO data in India)
*
local hhdata "~/dropbox/wsp/india/data/untouched/long/hhold_panel.dta"
local chdata "~/dropbox/wsp/india/data/untouched/long/child_panel.dta"
local cgdata "~/dropbox/wsp/india/data/untouched/long/cgiver_panel.dta"
*local sodata "~/dropbox/wsp/peru/data/untouched/endline/SO.dta"

* ID variables to use as household / person keys
* could be a single variable to identify unique HHs or people + survey round
* -- just needs to be a unique key
local cluster "tzwsp_id1 survid"
local hhids "tzwsp_id1 tzwsp_id2 survid"
local pids  "tzwsp_id1 tzwsp_id2 id survid"

* Hemoglobin level variable
* (name may differ by country, depending on whether altitude adjustment is required)
* g33_14 (no alt adjustment), g33_14b (w/ alt adjustment) 
local hbvar "g33_14" 

* Output file directory
local outdir "~/dropbox/wsp/india/data/temp"

* Prefix for output file names (e.g., country name)
local prefix "India"

* Directory with WHO i-growup reference data 
* (included with the common variable program distribution)
* (for anthropometric Z-score calculation)
local whodir "~/dropbox/wsp/programs/common-v2-2011-09-09/3 who-igrowup"

* Directory that includes programs to calculate derived variables
local pgdir "~/dropbox/wsp/programs/common-v2-2011-09-09"


*--------------------------------------------
* Load programs to calculate derived variables
*--------------------------------------------
qui do "`pgdir'/0 wsp-tolower.do"
qui do "`pgdir'/1 wsp-date-age-sex.do"
qui do "`pgdir'/2 wsp-illness.do"
qui do "`pgdir'/3 wsp-anthro.do"
qui do "`pgdir'/4 wsp-ASQ-bl.do"
qui do "`pgdir'/4 wsp-ASQ-el.do"
qui do "`pgdir'/5 wsp-anemia.do"
* group 6 not completed
qui do "`pgdir'/7 wsp-sanitation.do"
qui do "`pgdir'/8 wsp-water.do"
qui do "`pgdir'/9 wsp-hygiene-hh-India-Indo.do"
qui do "`pgdir'/10 wsp-hygiene-caregiver.do"
* group 11 not completed
* group 12 not completed


*--------------------------------------------
* Convert variable names to lower case
*--------------------------------------------
use `hhdata', clear
tolower *
sort `hhids'
tempfile hhdata2
save `hhdata2'

use `chdata'
tolower *
sort `pids'
tempfile chdata2
save `chdata2'

use `cgdata'
tolower *
sort `pids'
tempfile cgdata2
save `cgdata2'

*--------------------------------------------
* India-specific dataset standardization
*--------------------------------------------

use `chdata2', clear


** Age in months + days (no birth dates available)
gen agemth = g01_05y * 12 + g01_05m
	replace agemth = g01_05y * 12 + 6 if g01_05m < 0
	replace agemth = 0.5 if agemth == 0
	label var agemth "Age in months"
	
gen ageday = agemth * 30.4375
	label var ageday "Age in days"

** sex
gen sex = g01_02
	replace sex = 1 if sex == -95
	label var sex "Sex"
	label values sex G01_02
	
** convert module 19 from numeric to string
local vlist "g19_*d*"
foreach var of varlist g19_*d* {
	gen x`var' = string(`var')
	local vlab : var lab `var'
	drop `var'
	rename x`var' `var'
	label var `var' "`vlab'"
}

save `chdata2', replace


use `hhdata2', clear

** assume missing water treatment at baseline is "No"
forvalues i = 1/7 {
	replace g08_05_`i' = 2 if g08_05_`i' ==.
}

** recode water treatment indicator at endline (appears to not have been asked)
replace g08_04 = 1 if survid==2

** Households with missing sanitation facility assumed to be no facility
replace g09_01 = 12 if g09_01 == .

** OD practices among other HHs (set to missing for now)
** looks like this was asked as a single question in India g09_28
gen g09_28_a = .
gen g09_28_b = .
gen g09_28_c = .

save `hhdata2', replace

*--------------------------------------------
* 1 dates, age sex
*--------------------------------------------
/*
COMMENTED OUT FOR INDIA BECAUSE NO BIRTH DATES ARE APPARENT IN THE DATA
RESORTING TO CRUDE CALCULATIONS ABOVE BASED ON YEAR/MONTH

wspdateage, idvars(`pids') mergevars(`hhids') clusterid(`cluster') hhfile(`hhdata2') chfile(`chdata2') outfile("`outdir'/`prefix'-dateage.dta")

* merge age / sex information back to the child
* data because the age in days is needed repeatedly
* in the calculations below (as is sex)

keep `pids' intdate birthdate ageday agemth sex
sort `pids'

qui merge `pids' using `chdata2'
assert _merge!=2
drop _merge

save `chdata2', replace

*/


*--------------------------------------------
* 2 Illness
*--------------------------------------------

use `chdata2', clear
wspillness, idvars(`pids') outfile("`outdir'/`prefix'-illness.dta")


*--------------------------------------------
* 3 anthropometric Z-scores
*--------------------------------------------
use `chdata2', clear
wspanthro, idvars(`pids') whodir(`whodir')  outdir(`outdir') outfile("`prefix'-anthro.dta")


*--------------------------------------------
* 4 ASQ Baseline  (not collected in Endline)
*--------------------------------------------
use `chdata2', clear
keep if survid == 1
wspASQbl, idvars(`pids') outfile("`outdir'/`prefix'-ASQ.dta")

/*
use `chdata2', clear
keep if survid == 2
wspASQel, idvars(`pids') outfile("`outdir'/`prefix'-ASQel.dta")

* now append baseline + endline datasets
use "`outdir'/`prefix'-ASQbl.dta", clear
append using "`outdir'/`prefix'-ASQel.dta"
sort `pids'
save "`outdir'/`prefix'-ASQ.dta", replace
*/


*--------------------------------------------
* 5 Anemia
*--------------------------------------------
use `chdata2', clear
wspanemia, idvars(`pids') hbvar(`hbvar') outfile("`outdir'/`prefix'-anemia.dta")


*--------------------------------------------
* 6 water and stool microbiology
*--------------------------------------------
* Not complete

*--------------------------------------------
* 7 sanitation
*--------------------------------------------

use `hhdata2', clear
wspsanitation, idvars(`hhids') outfile("`outdir'/`prefix'-sanitation.dta")


*--------------------------------------------
* 8 water
*--------------------------------------------
use `hhdata2', clear
wspwater, idvars(`hhids') outfile("`outdir'/`prefix'-water.dta")


*--------------------------------------------
* 9 hygiene and handwashing, HH
*--------------------------------------------

use `hhdata2', clear
wsphygienehh,  idvars(`hhids') outfile("`outdir'/`prefix'-hygienehh.dta")


*--------------------------------------------
* 10 hygiene and handwashing, Caregiver
*--------------------------------------------
use `cgdata2', clear
wsphygienecg,  idvars(`pids') outfile("`outdir'/`prefix'-hygienecg.dta")


*--------------------------------------------
* Merge together Household level variables
* into a single dataset
*--------------------------------------------

use "`outdir'/`prefix'-sanitation.dta", clear

sort `hhids'
merge `hhids' using "`outdir'/`prefix'-water.dta"
assert _merge == 3
drop _merge

sort `hhids'
merge `hhids' using "`outdir'/`prefix'-hygienehh.dta"
assert _merge == 3
drop _merge

label data "Household Level Derived Variables, WSP IE"
sort `hhids'
save "`outdir'/`prefix'-derived-hh.dta", replace

*--------------------------------------------
* Merge together Child level variables
* into a single dataset
*--------------------------------------------
/* date + age dataset commented out -- not created above b/c missing birth dates
use "`outdir'/`prefix'-dateage.dta", clear

sort `pids'
merge `pids' using "`outdir'/`prefix'-illness.dta"
assert _merge==3
drop _merge
*/

use "`outdir'/`prefix'-illness.dta", clear

sort `pids'
merge `pids' using "`outdir'/`prefix'-anthro.dta"
tab _merge
assert _merge!=2
drop _merge

sort `pids'
merge `pids' using "`outdir'/`prefix'-ASQ.dta"
tab _merge
assert _merge!=2
drop _merge g25*

sort `pids'
merge `pids' using "`outdir'/`prefix'-anemia.dta"
assert _merge==3
drop _merge


label data "Child Level Derived Variables, WSP IE"
sort `hhids'
save "`outdir'/`prefix'-derived-ch.dta", replace

*--------------------------------------------
* Merge together Caregiver level variables
* into a single dataset
* NOTE: no merge currently required
*--------------------------------------------
use "`outdir'/`prefix'-hygienecg.dta", clear
sort `pids'

label data "Caregiver Level Derived Variables, WSP IE"
sort `pids'
save "`outdir'/`prefix'-derived-cg.dta", replace



log close
exit
