
*---------------------------------------------
* Program    : 10 wsp-hygiene-caregiver.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 1.0 (2011-07-12)

A general program to calculate derived Caregiver
hygiene and handwashing variables for the WSP IE 
endline datasets.


Arguments:
idvars()    : Variable name list of identifier variables (should uniquely identify individuals)

outfile()   : Text string for a directory/filename for the output dataset

*/
*---------------------------------------------

capture program drop wsphygienecg
program define wsphygienecg
version 10

syntax , idvars(varlist) outfile(string)



*--------------------------------------------
* Cleanliness index of caregiver hands 
* (index based on observation of nails, palms, 
*  and fingerpads)
*--------------------------------------------

gen handcleanindex = (g25b_07 + g25b_08 + g25b_09)
	replace handcleanindex = . if (g25b_06==2) | inlist(g25b_07,-96,-99) | inlist(g25b_08,-96,-99) | inlist(g25b_09,-96,-99)
	label var handcleanindex "Cleanliness index of caregiver hands: nails, palms, fingerpads"
	
*--------------------------------------------
* Handwashing with soap after fecal contact 
* during previous day
*--------------------------------------------

gen byte reportsoapfecal = inlist(g25b_04,3,4) | (g25b_05_03==1) | (g25b_05_04==1)
	replace reportsoapfecal = . if (g25b_02==2) | (g25b_03==-99)
	label define YN 1 "Yes" 0 "No"
	label values reportsoapfecal YN
	label var reportsoapfecal "HW w/ soap after fecal contact in last 24hr"

*--------------------------------------------
* Handwashing with soap before food 
* preparation during previous day
*--------------------------------------------

gen byte reportsoapfdprep = (g25b_04==8) | (g25b_05_08==1)
	replace reportsoapfdprep = . if (g25b_02==2) | (g25b_03==-99)
	label values reportsoapfdprep YN
	label var reportsoapfdprep "HW w/ soap before food prep in last 24hr"

*--------------------------------------------
* Handwashing with soap before feeding child
* during previous day
*--------------------------------------------

gen byte reportsoapfeed = (g25b_04==9) | (g25b_05_09==1)
	replace reportsoapfeed = . if (g25b_02==2) | (g25b_03==-99)
	label values reportsoapfeed YN
	label var reportsoapfeed "HW w/ soap before feeding child in last 24hr"

*--------------------------------------------
* Handwashing with soap before eating 
* during previous day
*--------------------------------------------

gen byte reportsoapeat = (g25b_04==14) | (g25b_05_14==1)
	replace reportsoapeat = . if (g25b_02==2) | (g25b_03==-99)
	label values reportsoapeat YN
	label var reportsoapeat "HW w/ soap befor eating in last 24hr"


*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
keep `idvars' handcleanindex - reportsoapeat 
compress

label data "Caregiver Hygiene and Handwashing Variables"

save "`outfile'", replace

codebook, c

end wsphygienecg




