
*---------------------------------------------
* Program    : 11 wsp-structured-obs.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

A general program to calculate derived 
variables from structured observation data
collected at endline in the handwashing countries


Arguments:
idvars()    : Variable name list of identifier variables (should uniquely identify households)

outfile()   : Text string for a directory/filename for the output dataset

Version 3.0 updates:
Restricted the SO incidators to be missing for events that are not of the specific type
(fecal contact, food prep, child feeding, eating)

*/
*---------------------------------------------

capture program drop wspSO
program define wspSO
version 10

syntax , idvars(varlist) outfile(string)



*--------------------------------------------
* HW with soap after fecal contact
*--------------------------------------------

gen byte Obsoapfecal = inlist(ob3,8,9,10) & inlist(ob7,1,2,3,4)
	replace Obsoapfecal = . if !inlist(ob3,8,9,10)
	replace Obsoapfecal = . if (ob3==. & ob7==.)
	label var Obsoapfecal "HW with soap after fecal contact"

*--------------------------------------------
* HW with soap after before food preparation
*--------------------------------------------

gen byte Obsoapfdprep = inlist(ob3,2,3) & inlist(ob7,1,2,3,4)
	replace Obsoapfdprep = . if !inlist(ob3,2,3)
	replace Obsoapfdprep = . if (ob3==. & ob7==.)
	label var Obsoapfdprep "HW with soap after before food preparation"
	
*--------------------------------------------
* HW with soap before feeding a child
*--------------------------------------------

gen byte Obsoapfeed = inlist(ob3,6,7) & inlist(ob7,1,2,3,4)
	replace Obsoapfeed = . if !inlist(ob3,6,7)
	replace Obsoapfeed = . if (ob3==. & ob7==.)
	label var Obsoapfeed "HW with soap before feeding a child"
	
*--------------------------------------------
* HW with soap before eating
*--------------------------------------------

gen byte Obsoapeat = inlist(ob3,4) & inlist(ob7,1,2,3,4)
	replace Obsoapeat = . if !inlist(ob3,4)
	replace Obsoapeat = . if (ob3==. & ob7==.)
	label var Obsoapeat "HW with soap before eating"
	

*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
compress

label data "Structured Observation Data"

save "`outfile'", replace

codebook, c

end wspSO




