
*---------------------------------------------
* Program    : 8 wsp-water.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

A general program to calculate a derived
water variables for the WSP IE endline datasets.
Documentation / references are cited below in the code.

The program is run on the household level dataset.
It requires information from modules 7 and 8.

This program also requires the variable "survid", a survey ID variable
that identifies 1 = Baseline and 2 = Endline


Arguments:
idvars()    : Variable name list of identifier variables (should uniquely identify households)

outfile()   : Text string for a directory/filename for the output dataset


*/
*---------------------------------------------

capture program drop wspwater
program define wspwater
version 10

syntax , idvars(varlist) outfile(string)

*---------------------------------------------
* JMP defined improved water sources
* http://www.who.int/water_sanitation_health/monitoring/core_questions/en/index.html
*
* note households with "other" sources are classified into Unimproved

gen byte JMPh2o = 0 if  inlist(g07_01, 6,8,10,11,12,-96)
	replace JMPh2o = 1 if inlist(g07_01, 1,2,3,4,5,7,9,13)
	replace JMPh2o = . if (g07_01 == .)
	label define JMPh2o 0 "Unimproved water source" 1 "Improved water source"
	label values JMPh2o JMPh2o
	label var JMPh2o "JMP defined improved water source"
	
gen watsource = g07_01
	label values watsource G07_01
	label var watsource "Main water source"
	
*---------------------------------------------
	


*---------------------------------------------
* Water scarcity
*---------------------------------------------

gen byte h2oscarce = inlist(g07_06c,3,4)
	replace h2oscarce = . if inlist(g07_06c,.,-99) | survid==1
	label define YN 1 "Yes" 0 "No"
	label values h2oscarce YN
	label var h2oscarce "Water is scarce at source > 1 time per week"
	
gen byte h2osatisf = (g07_07 ==1)
	replace h2osatisf = . if inlist(g07_07,.,-99)
	label values h2osatisf YN
	label var h2osatisf "Satisfied with water quantity at source"

*---------------------------------------------
* Water storage
*---------------------------------------------

gen byte h2ostore = (g08_01 == 1)
	replace h2ostore = . if (g08_01 == .)
	label values h2ostore YN
	label var h2ostore "Stores drinking water in the home"

*---------------------------------------------
* Water treatment
*---------------------------------------------

gen byte h2otreat = (g08_05_1==1 & g08_06_1==1) | (g08_05_2==1 & g08_06_2==1) | (g08_05_3==1 & g08_06_3==1) | (g08_05_4==1 & g08_06_4==1) | (g08_05_5==1 & g08_06_5==1) | (g08_05_6==1 & g08_06_6==1) | (g08_05_7==1 & g08_06_7==1) 
	replace h2otreat = 0 if !inlist(g08_04,1,2)
	* recode for baseline values, where method specific frequency not asked
	replace h2otreat = 1 if (survid==1) & (g08_06==1) & (g08_05_1==1 | g08_05_2==1 | g08_05_3==1 | g08_05_4==1 | g08_05_5==1 | g08_05_6==1 | g08_05_7==1 ) 
	label values h2otreat YN
	label var h2otreat "Self-reported drinking water treatment (any method), every day last 7 days"
	
gen byte h2oboil = (g08_05_1==1 & g08_06_1==1) 
	replace h2oboil = 0 if !inlist(g08_04,1,2)
	* recode for baseline values, where method specific frequency not asked
	replace h2oboil = 1 if (survid==1) & (g08_05_1==1) & (g08_06==1)
	label values h2oboil YN
	label var h2oboil "Self-reported boils drinking water, every day last 7 days"

* Suggested Vietnam Adaptation
* g06_06_1 ... _7 replaced with g08_06 (no method specific questions asked at endline)
*gen byte h2otreat = (g08_05_1==1 & g08_06==1) | (g08_05_2==1 & g08_06==1) | (g08_05_3==1 & g08_06==1) | (g08_05_4==1 & g08_06==1) | (g08_05_5==1 & g08_06==1) | (g08_05_6==1 & g08_06==1) | (g08_05_7==1 & g08_06==1) 
* gen byte h2oboil = (g08_05_1==1 & g08_06==1) 

	

*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
keep `idvars' JMPh2o - h2oboil
compress

label data "Standard Water Variables"

save "`outfile'", replace

codebook, c

end wspwater




