
*---------------------------------------------
* Program    : 9 wsp-hygiene-hh-India-Indo.do
* Programmer : Ben Arnold (benarnold@berkeley.edu)
/*

Version Number 2.0 (2011-09-09)

A VERSION FOR SANITATION COUNTRIES IN WHICH
QUESTIONS G.12B.12, G.12B.22 AND G.12B.24 WERE NOT ASKED.


A general program to calculate derived HH
hygiene and handwashing variables for the WSP IE 
endline datasets.

It requires variables from Modules 11 and 12b

This program also requires the variable "survid", a survey ID variable
that identifies 1 = Baseline and 2 = Endline

Arguments:
idvars()    : Variable name list of identifier variables (should uniquely identify households)

outfile()   : Text string for a directory/filename for the output dataset

*/
*---------------------------------------------

capture program drop wsphygienehh
program define wsphygienehh
version 10

syntax , idvars(varlist) outfile(string)



*--------------------------------------------
* Garbage observed in the kitchen or house
*--------------------------------------------

gen byte garbage = (g11_01==1)
	replace garbage = . if inlist(g11_01,-99,.)
	label define YN 1 "Yes" 0 "No"
	label values garbage YN
	label var garbage "Garbage obs. in kitchen or house"
	
*--------------------------------------------
* Food is completely covered
*--------------------------------------------

gen byte foodcov = (g11_02==1)
	replace foodcov = . if inlist(g11_02,-99,.)
	label values foodcov YN
	label var foodcov "Food is completely covered"
	
*--------------------------------------------
* Presence of soap anywhere in the home
*
*--------------------------------------------

* Note: g12b_22 was not asked in Indonesia or India at endline.
* The following variable is not valid for those datasets.
/*
gen byte soaphome = (g12b_22_1==1) | (g12b_22_2==1) | (g12b_22_3==1) | (g12b_22_4==1) | (g12b_22_5==1) | inlist(g12b_24,1,2,3,4,5)
	replace soaphome = . if survid==1
	label values soaphome YN
	label var soaphome "Soap present anywhere in the home"
*/

*--------------------------------------------
* Presence of soap & water at the handwashing
* place used post-defecation
*--------------------------------------------

gen byte soapwattoilet = (g12b_04==1) & ( (g12b_05_1==1) | (g12b_05_2==1) | (g12b_05_3==1) | (g12b_05_4==1) | (g12b_05_5==1) )
	replace soapwattoilet = . if (g12b_02==-98) | (g12b_04==-99) | (g12b_05_99==1)
	label values soapwattoilet YN
	label var soapwattoilet "Soap & water present, HW place used post-defecation"

* Note: g12b_12 was not asked in Indonesia or India at endline.
* The following variable is not valid for those datasets.
/*
gen byte soapwatkitchen = (g12b_11==1) & ( (g12b_12_1==1) | (g12b_12_2==1) | (g12b_12_3==1) | (g12b_12_4==1) | (g12b_12_5==1) )
	replace soapwatkitchen = . if (g12b_08==-98) | (g12b_11==-99) | (g12b_12_99==1)
	label values soapwatkitchen YN
	label var soapwatkitchen "Soap & water present, HW place used before food prep."
*/

*---------------------------------------------
* Output the dataset with the added variables
*---------------------------------------------

di as res _n "Compressing and saving data..."
keep `idvars' garbage - soapwattoilet 
compress

label data "Household Hygiene and Handwashing Variables"

save "`outfile'", replace

codebook, c

end wsphygienehh




